package DBIx::ConnectInfo::Auth;

use Moose;

has 'user' => (is => 'ro', isa => 'Str', required => 1);
has 'pass' => (is => 'ro', isa => 'Str', required => 1);

1;

__END__

=head1 NAME

DBIx::ConnectInfo::Auth - base class for a set of username / password
credentials for database access

=head1 SYNOPSIS

    # Intended to be subclassed, one subclass for each set of credentials
    # Naming convention: NAMESPACE::Auth::ROLE::ENV
    package Foo::Auth::Web::Dev;
    use Moose;
    extends 'DBIx::ConnectInfo::Auth';

    has '+user' => ( default => 'my_user' );
    has '+pass' => ( default => 'my_pass' );

    1;


    # Usage (usually done by DBIx::ConnectInfo itself)
    $auth = Foo::Auth::Web::Dev->new;
    print $auth->user, $auth->pass;


=head1 DESCRIPTION

DBIx::ConnectInfo::Auth is a trivial base class used for defining a 
username / password pair, for use by DBIx::ConnectInfo. It simply
defines 'user' and 'pass' slots (and methods), which are intended to
by defined by subclasses using a Moose default. (Usernames and password
pairs are defined in separate files, rather than aggregated in a config
file or something because we want to be able to apply different file
permissions to different pairs for security.)

=head1 METHODS

=over 4

=item user

Return the 'user' username value from the object.

=item pass

Return the 'pass' password value from the object.

=back

=head1 SEE ALSO

DBIx::ConnectInfo

=head1 AUTHOR

Gavin Carr, C<< <gavin at openfusion.com.au> >>

=cut

