#!perl

use Test::More tests => 20;

BEGIN {
  use lib -d 't' ? 't/lib' : 'lib';
  use_ok( 'Test::ConnectInfo' );
}

my %credentials = (
  webdev  => [ 'dbi:Pg:dbname=foobar', 'webdev', 'webdevpass', ],
  webtest => [ 'dbi:Pg:dbname=foobar_test', 'webtest', 'webtestpass', ],
  webprod => [ 'dbi:Pg:dbname=foobar;host=db1', 'webprod', 'webprodpass', ],
);

sub check_creds {
  my ($given, $expected, $testname) = @_;
  if (ref $given eq 'ARRAY') {
    is_deeply($given, $credentials{$expected}, $testname);
  }
  else {
    my @info = $given->info;
    is_deeply(\@info, $credentials{$expected}, $testname); 
  }
}

my $ci;

# Defaults
ok($ci = Test::ConnectInfo->new, 'defaults constructor');
check_creds($ci, 'webdev', 'defaults (webdev)');

# Env dev
ok($ci = Test::ConnectInfo->new( env => 'dev' ), 'env dev constructor');
check_creds($ci, 'webdev', 'env dev (webdev)');

# Role web
ok($ci = Test::ConnectInfo->new( role => 'web' ), 'role web constructor');
check_creds($ci, 'webdev', 'role web (webdev)');

# Env dev, role web
ok($ci = Test::ConnectInfo->new( env => 'dev', role => 'web' ), 'env dev, role web constructor');
check_creds($ci, 'webdev', 'env dev, role web (webdev)');

# Env test
ok($ci = Test::ConnectInfo->new( env => 'test' ), 'env test constructor');
check_creds($ci, 'webtest', 'env test (webtest)');

# Env prod
ok($ci = Test::ConnectInfo->new( env => 'prod' ), 'env prod constructor');
check_creds($ci, 'webprod', 'env prod (webprod)');

# Env test, role web
ok($ci = Test::ConnectInfo->new( env => 'test', role => 'web' ), 'env test, role web constructor');
check_creds($ci, 'webtest', 'env test, role web (webtest)');

# Env prod, role web
ok($ci = Test::ConnectInfo->new( env => 'prod', role => 'web' ), 'env prod, role web constructor');
check_creds($ci, 'webprod', 'env prod, role web (webprod)');


# info() constructor

# Defaults
check_creds([ Test::ConnectInfo->info ], 
  'webdev', 'defaults (webdev) via info()');

# Env test
check_creds([ Test::ConnectInfo->info( env => 'test' ) ], 
  'webtest', 'env test (webtest) via info()');

# Env prod, role web
check_creds([ Test::ConnectInfo->info( env => 'prod', role => 'web' ) ], 
  'webprod', 'env prod, role web (webprod) via info()');

